# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/Colors.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/Colors.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\006ColorsH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!opencannabis/content/Colors.proto\x12\x14opencannabis.content\";\n\rRGBAColorSpec\x12\t\n\x01r\x18\x01 \x01(\x04\x12\t\n\x01g\x18\x02 \x01(\x04\x12\t\n\x01\x62\x18\x03 \x01(\x04\x12\t\n\x01\x61\x18\x04 \x01(\x04\"/\n\x0cHSBColorSpec\x12\t\n\x01h\x18\x01 \x01(\x04\x12\t\n\x01s\x18\x02 \x01(\x04\x12\t\n\x01\x62\x18\x03 \x01(\x04\";\n\rCMYKColorSpec\x12\t\n\x01\x63\x18\x01 \x01(\x04\x12\t\n\x01m\x18\x02 \x01(\x04\x12\t\n\x01y\x18\x03 \x01(\x04\x12\t\n\x01k\x18\x04 \x01(\x04\"\xf4\x01\n\x05\x43olor\x12\x37\n\x08standard\x18\x01 \x01(\x0e\x32#.opencannabis.content.StandardColorH\x00\x12\r\n\x03hex\x18\x02 \x01(\tH\x00\x12\x33\n\x04rgba\x18\x03 \x01(\x0b\x32#.opencannabis.content.RGBAColorSpecH\x00\x12\x31\n\x03hsb\x18\x04 \x01(\x0b\x32\".opencannabis.content.HSBColorSpecH\x00\x12\x33\n\x04\x63myk\x18\x05 \x01(\x0b\x32#.opencannabis.content.CMYKColorSpecH\x00\x42\x06\n\x04spec\"\xc4\x01\n\x0b\x43olorScheme\x12,\n\x07primary\x18\x01 \x01(\x0b\x32\x1b.opencannabis.content.Color\x12.\n\tsecondary\x18\x02 \x01(\x0b\x32\x1b.opencannabis.content.Color\x12*\n\x05\x61lert\x18\x03 \x01(\x0b\x32\x1b.opencannabis.content.Color\x12+\n\x06shades\x18\x04 \x03(\x0b\x32\x1b.opencannabis.content.Color*\x87\x01\n\rStandardColor\x12\x15\n\x11UNSPECIFIED_COLOR\x10\x00\x12\x07\n\x03RED\x10\x01\x12\t\n\x05GREEN\x10\x02\x12\x08\n\x04\x42LUE\x10\x03\x12\n\n\x06YELLOW\x10\x04\x12\n\n\x06PURPLE\x10\x05\x12\n\n\x06ORANGE\x10\x06\x12\x08\n\x04PINK\x10\x07\x12\x08\n\x04GRAY\x10\x08\x12\t\n\x05\x42ROWN\x10\tB2\n\x1eio.opencannabis.schema.contentB\x06\x43olorsH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_STANDARDCOLOR = _descriptor.EnumDescriptor(
  name='StandardColor',
  full_name='opencannabis.content.StandardColor',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_COLOR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLUE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PURPLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORANGE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PINK', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRAY', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROWN', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=677,
  serialized_end=812,
)
_sym_db.RegisterEnumDescriptor(_STANDARDCOLOR)

StandardColor = enum_type_wrapper.EnumTypeWrapper(_STANDARDCOLOR)
UNSPECIFIED_COLOR = 0
RED = 1
GREEN = 2
BLUE = 3
YELLOW = 4
PURPLE = 5
ORANGE = 6
PINK = 7
GRAY = 8
BROWN = 9



_RGBACOLORSPEC = _descriptor.Descriptor(
  name='RGBAColorSpec',
  full_name='opencannabis.content.RGBAColorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='opencannabis.content.RGBAColorSpec.r', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='g', full_name='opencannabis.content.RGBAColorSpec.g', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='opencannabis.content.RGBAColorSpec.b', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='opencannabis.content.RGBAColorSpec.a', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=118,
)


_HSBCOLORSPEC = _descriptor.Descriptor(
  name='HSBColorSpec',
  full_name='opencannabis.content.HSBColorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='h', full_name='opencannabis.content.HSBColorSpec.h', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='opencannabis.content.HSBColorSpec.s', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='opencannabis.content.HSBColorSpec.b', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=167,
)


_CMYKCOLORSPEC = _descriptor.Descriptor(
  name='CMYKColorSpec',
  full_name='opencannabis.content.CMYKColorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='c', full_name='opencannabis.content.CMYKColorSpec.c', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m', full_name='opencannabis.content.CMYKColorSpec.m', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='opencannabis.content.CMYKColorSpec.y', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k', full_name='opencannabis.content.CMYKColorSpec.k', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=228,
)


_COLOR = _descriptor.Descriptor(
  name='Color',
  full_name='opencannabis.content.Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='standard', full_name='opencannabis.content.Color.standard', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hex', full_name='opencannabis.content.Color.hex', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rgba', full_name='opencannabis.content.Color.rgba', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hsb', full_name='opencannabis.content.Color.hsb', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmyk', full_name='opencannabis.content.Color.cmyk', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.content.Color.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=231,
  serialized_end=475,
)


_COLORSCHEME = _descriptor.Descriptor(
  name='ColorScheme',
  full_name='opencannabis.content.ColorScheme',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary', full_name='opencannabis.content.ColorScheme.primary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary', full_name='opencannabis.content.ColorScheme.secondary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alert', full_name='opencannabis.content.ColorScheme.alert', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shades', full_name='opencannabis.content.ColorScheme.shades', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=674,
)

_COLOR.fields_by_name['standard'].enum_type = _STANDARDCOLOR
_COLOR.fields_by_name['rgba'].message_type = _RGBACOLORSPEC
_COLOR.fields_by_name['hsb'].message_type = _HSBCOLORSPEC
_COLOR.fields_by_name['cmyk'].message_type = _CMYKCOLORSPEC
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['standard'])
_COLOR.fields_by_name['standard'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['hex'])
_COLOR.fields_by_name['hex'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['rgba'])
_COLOR.fields_by_name['rgba'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['hsb'])
_COLOR.fields_by_name['hsb'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['cmyk'])
_COLOR.fields_by_name['cmyk'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLORSCHEME.fields_by_name['primary'].message_type = _COLOR
_COLORSCHEME.fields_by_name['secondary'].message_type = _COLOR
_COLORSCHEME.fields_by_name['alert'].message_type = _COLOR
_COLORSCHEME.fields_by_name['shades'].message_type = _COLOR
DESCRIPTOR.message_types_by_name['RGBAColorSpec'] = _RGBACOLORSPEC
DESCRIPTOR.message_types_by_name['HSBColorSpec'] = _HSBCOLORSPEC
DESCRIPTOR.message_types_by_name['CMYKColorSpec'] = _CMYKCOLORSPEC
DESCRIPTOR.message_types_by_name['Color'] = _COLOR
DESCRIPTOR.message_types_by_name['ColorScheme'] = _COLORSCHEME
DESCRIPTOR.enum_types_by_name['StandardColor'] = _STANDARDCOLOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RGBAColorSpec = _reflection.GeneratedProtocolMessageType('RGBAColorSpec', (_message.Message,), {
  'DESCRIPTOR' : _RGBACOLORSPEC,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.RGBAColorSpec)
  })
_sym_db.RegisterMessage(RGBAColorSpec)

HSBColorSpec = _reflection.GeneratedProtocolMessageType('HSBColorSpec', (_message.Message,), {
  'DESCRIPTOR' : _HSBCOLORSPEC,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.HSBColorSpec)
  })
_sym_db.RegisterMessage(HSBColorSpec)

CMYKColorSpec = _reflection.GeneratedProtocolMessageType('CMYKColorSpec', (_message.Message,), {
  'DESCRIPTOR' : _CMYKCOLORSPEC,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.CMYKColorSpec)
  })
_sym_db.RegisterMessage(CMYKColorSpec)

Color = _reflection.GeneratedProtocolMessageType('Color', (_message.Message,), {
  'DESCRIPTOR' : _COLOR,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.Color)
  })
_sym_db.RegisterMessage(Color)

ColorScheme = _reflection.GeneratedProtocolMessageType('ColorScheme', (_message.Message,), {
  'DESCRIPTOR' : _COLORSCHEME,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.ColorScheme)
  })
_sym_db.RegisterMessage(ColorScheme)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Distance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Distance.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/geo/Distance.proto\x12\x10opencannabis.geo\x1a\x19gust/core/datamodel.proto\"\xc4\x01\n\x10LocationAccuracy\x12N\n\x08\x65stimate\x18\x01 \x01(\x08\x42<\xc2\xb5\x03\x38\x12\x36Specifies whether this accuracy rating is an estimate.\x12`\n\x05value\x18\x02 \x01(\x0b\x32\x1f.opencannabis.geo.DistanceValueB0\xc2\xb5\x03,\x12*Distance value for the accuracy specified.\"\xaf\x01\n\rDistanceValue\x12q\n\x04unit\x18\x01 \x01(\x0e\x32\x1e.opencannabis.geo.DistanceUnitBC\xc2\xb5\x03?\x12=Specifies the unit of measurement employed for this distance.\x12+\n\x05value\x18\x03 \x01(\x01\x42\x1c\xc2\xb5\x03\x18\x12\x16\x41\x63tual distance value.\"\xb8\x02\n\x08\x44istance\x12G\n\x08\x65stimate\x18\x01 \x01(\x08\x42\x35\xc2\xb5\x03\x31\x12/Specifies whether this distance is an estimate.\x12~\n\x08\x61\x63\x63uracy\x18\x02 \x01(\x0b\x32\".opencannabis.geo.LocationAccuracyBH\xc2\xb5\x03\x44\x12\x42Specifies the accuracy estimate for the distance values, if known.\x12\x63\n\x04unit\x18\x03 \x01(\x0e\x32\x1e.opencannabis.geo.DistanceUnitB5\xc2\xb5\x03\x31\x12/Specifies whether this distance is an estimate.*m\n\x0c\x44istanceUnit\x12\n\n\x06METERS\x10\x00\x12\n\n\x06INCHES\x10\x01\x12\x08\n\x04\x46\x45\x45T\x10\x02\x12\x0f\n\x0bMILLIMETERS\x10\x03\x12\x0f\n\x0b\x43\x45NTIMETERS\x10\x04\x12\x0e\n\nKILOMETERS\x10\x05\x12\t\n\x05MILES\x10\x06\x42&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])

_DISTANCEUNIT = _descriptor.EnumDescriptor(
  name='DistanceUnit',
  full_name='opencannabis.geo.DistanceUnit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='METERS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INCHES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MILLIMETERS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CENTIMETERS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KILOMETERS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MILES', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=772,
  serialized_end=881,
)
_sym_db.RegisterEnumDescriptor(_DISTANCEUNIT)

DistanceUnit = enum_type_wrapper.EnumTypeWrapper(_DISTANCEUNIT)
METERS = 0
INCHES = 1
FEET = 2
MILLIMETERS = 3
CENTIMETERS = 4
KILOMETERS = 5
MILES = 6



_LOCATIONACCURACY = _descriptor.Descriptor(
  name='LocationAccuracy',
  full_name='opencannabis.geo.LocationAccuracy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='estimate', full_name='opencannabis.geo.LocationAccuracy.estimate', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0038\0226Specifies whether this accuracy rating is an estimate.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.geo.LocationAccuracy.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*Distance value for the accuracy specified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=277,
)


_DISTANCEVALUE = _descriptor.Descriptor(
  name='DistanceValue',
  full_name='opencannabis.geo.DistanceValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.geo.DistanceValue.unit', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003?\022=Specifies the unit of measurement employed for this distance.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.geo.DistanceValue.value', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\030\022\026Actual distance value.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=455,
)


_DISTANCE = _descriptor.Descriptor(
  name='Distance',
  full_name='opencannabis.geo.Distance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='estimate', full_name='opencannabis.geo.Distance.estimate', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Specifies whether this distance is an estimate.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.geo.Distance.accuracy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003D\022BSpecifies the accuracy estimate for the distance values, if known.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.geo.Distance.unit', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Specifies whether this distance is an estimate.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=458,
  serialized_end=770,
)

_LOCATIONACCURACY.fields_by_name['value'].message_type = _DISTANCEVALUE
_DISTANCEVALUE.fields_by_name['unit'].enum_type = _DISTANCEUNIT
_DISTANCE.fields_by_name['accuracy'].message_type = _LOCATIONACCURACY
_DISTANCE.fields_by_name['unit'].enum_type = _DISTANCEUNIT
DESCRIPTOR.message_types_by_name['LocationAccuracy'] = _LOCATIONACCURACY
DESCRIPTOR.message_types_by_name['DistanceValue'] = _DISTANCEVALUE
DESCRIPTOR.message_types_by_name['Distance'] = _DISTANCE
DESCRIPTOR.enum_types_by_name['DistanceUnit'] = _DISTANCEUNIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocationAccuracy = _reflection.GeneratedProtocolMessageType('LocationAccuracy', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONACCURACY,
  '__module__' : 'opencannabis.geo.Distance_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.LocationAccuracy)
  })
_sym_db.RegisterMessage(LocationAccuracy)

DistanceValue = _reflection.GeneratedProtocolMessageType('DistanceValue', (_message.Message,), {
  'DESCRIPTOR' : _DISTANCEVALUE,
  '__module__' : 'opencannabis.geo.Distance_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.DistanceValue)
  })
_sym_db.RegisterMessage(DistanceValue)

Distance = _reflection.GeneratedProtocolMessageType('Distance', (_message.Message,), {
  'DESCRIPTOR' : _DISTANCE,
  '__module__' : 'opencannabis.geo.Distance_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Distance)
  })
_sym_db.RegisterMessage(Distance)


DESCRIPTOR._options = None
_LOCATIONACCURACY.fields_by_name['estimate']._options = None
_LOCATIONACCURACY.fields_by_name['value']._options = None
_DISTANCEVALUE.fields_by_name['unit']._options = None
_DISTANCEVALUE.fields_by_name['value']._options = None
_DISTANCE.fields_by_name['estimate']._options = None
_DISTANCE.fields_by_name['accuracy']._options = None
_DISTANCE.fields_by_name['unit']._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  OpenCannabis SDK for Python
  ---------------------------

  This library contains interfaces and objects for leveraging the OpenCannabis Specification
  and accompanying Protocol Definitions in Python.

"""

# Deps
from gust import core as gust



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/base/ProductKey.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.content import Name_pb2 as opencannabis_dot_content_dot_Name__pb2
from opencannabis.base import ProductKind_pb2 as opencannabis_dot_base_dot_ProductKind__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/base/ProductKey.proto',
  package='opencannabis.base',
  syntax='proto3',
  serialized_options=b'\n\033io.opencannabis.schema.baseB\016BaseProductKeyH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/base/ProductKey.proto\x12\x11opencannabis.base\x1a\x19gust/core/datamodel.proto\x1a\x1fopencannabis/content/Name.proto\x1a#opencannabis/base/ProductKind.proto\"\xc2\x01\n\x10ProductReference\x12P\n\x04name\x18\x01 \x01(\x0b\x32\x1a.opencannabis.content.NameB&\xc2\xb5\x03\"\x12 Specifies the name of a product.\x12\\\n\x03key\x18\x02 \x01(\x0b\x32\x1d.opencannabis.base.ProductKeyB0\xc2\xb5\x03,\x12*Specifies the key, if known, of a product.\"\xf4\x01\n\nProductKey\x12Y\n\x02id\x18\x01 \x01(\tBM\xc2\xb5\x03\x02\x08\x02\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03=\x12;Product ID, an opaque string that is usually autogenerated.\x12\x8a\x01\n\x04type\x18\x02 \x01(\x0e\x32\x1e.opencannabis.base.ProductKindB\\\xc2\xb5\x03\x02\x38\x01\xc2\xb5\x03R\x12PType of product the ID is referring to. In most cases this entry can be omitted.B7\n\x1bio.opencannabis.schema.baseB\x0e\x42\x61seProductKeyH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Name__pb2.DESCRIPTOR,opencannabis_dot_base_dot_ProductKind__pb2.DESCRIPTOR,])




_PRODUCTREFERENCE = _descriptor.Descriptor(
  name='ProductReference',
  full_name='opencannabis.base.ProductReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.base.ProductReference.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 Specifies the name of a product.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.base.ProductReference.key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*Specifies the key, if known, of a product.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=349,
)


_PRODUCTKEY = _descriptor.Descriptor(
  name='ProductKey',
  full_name='opencannabis.base.ProductKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.base.ProductKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\332\265\003\002\020\001\302\265\003=\022;Product ID, an opaque string that is usually autogenerated.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.base.ProductKey.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\0028\001\302\265\003R\022PType of product the ID is referring to. In most cases this entry can be omitted.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=596,
)

_PRODUCTREFERENCE.fields_by_name['name'].message_type = opencannabis_dot_content_dot_Name__pb2._NAME
_PRODUCTREFERENCE.fields_by_name['key'].message_type = _PRODUCTKEY
_PRODUCTKEY.fields_by_name['type'].enum_type = opencannabis_dot_base_dot_ProductKind__pb2._PRODUCTKIND
DESCRIPTOR.message_types_by_name['ProductReference'] = _PRODUCTREFERENCE
DESCRIPTOR.message_types_by_name['ProductKey'] = _PRODUCTKEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProductReference = _reflection.GeneratedProtocolMessageType('ProductReference', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTREFERENCE,
  '__module__' : 'opencannabis.base.ProductKey_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.base.ProductReference)
  })
_sym_db.RegisterMessage(ProductReference)

ProductKey = _reflection.GeneratedProtocolMessageType('ProductKey', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTKEY,
  '__module__' : 'opencannabis.base.ProductKey_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.base.ProductKey)
  })
_sym_db.RegisterMessage(ProductKey)


DESCRIPTOR._options = None
_PRODUCTREFERENCE.fields_by_name['name']._options = None
_PRODUCTREFERENCE.fields_by_name['key']._options = None
_PRODUCTKEY.fields_by_name['id']._options = None
_PRODUCTKEY.fields_by_name['type']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/pricing/PricingDescriptor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.commerce import Currency_pb2 as opencannabis_dot_commerce_dot_Currency__pb2
from opencannabis.structs.pricing import SaleDescriptor_pb2 as opencannabis_dot_structs_dot_pricing_dot_SaleDescriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/pricing/PricingDescriptor.proto',
  package='opencannabis.structs.pricing',
  syntax='proto3',
  serialized_options=b'\n%io.opencannabis.schema.product.structB\022ProductPricingSpecH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4opencannabis/structs/pricing/PricingDescriptor.proto\x12\x1copencannabis.structs.pricing\x1a$opencannabis/commerce/Currency.proto\x1a\x31opencannabis/structs/pricing/SaleDescriptor.proto\"=\n\x17PricingTierAvailability\x12\x0f\n\x07offered\x18\x01 \x01(\x08\x12\x11\n\tavailable\x18\x02 \x01(\x08\"\xd4\x01\n\x15UnitPricingDescriptor\x12\x33\n\x05price\x18\x01 \x01(\x0b\x32$.opencannabis.commerce.CurrencyValue\x12\x45\n\x06status\x18\x02 \x01(\x0b\x32\x35.opencannabis.structs.pricing.PricingTierAvailability\x12?\n\tdiscounts\x18\x03 \x03(\x0b\x32,.opencannabis.structs.pricing.SaleDescriptor\"\xb8\x01\n\x19WeightedPricingDescriptor\x12?\n\x06weight\x18\x01 \x01(\x0e\x32/.opencannabis.structs.pricing.PricingWeightTier\x12\x41\n\x04tier\x18\x02 \x01(\x0b\x32\x33.opencannabis.structs.pricing.UnitPricingDescriptor\x12\x17\n\x0fweight_in_grams\x18\x03 \x01(\x02\"\xe6\x01\n\x11PricingDescriptor\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).opencannabis.structs.pricing.PricingType\x12\x43\n\x04unit\x18\x14 \x01(\x0b\x32\x33.opencannabis.structs.pricing.UnitPricingDescriptorH\x00\x12K\n\x08weighted\x18\x15 \x01(\x0b\x32\x37.opencannabis.structs.pricing.WeightedPricingDescriptorH\x00\x42\x06\n\x04tier\"\x94\x01\n\x0eProductPricing\x12?\n\tdiscounts\x18\x01 \x03(\x0b\x32,.opencannabis.structs.pricing.SaleDescriptor\x12\x41\n\x08manifest\x18\x02 \x03(\x0b\x32/.opencannabis.structs.pricing.PricingDescriptor*%\n\x0bPricingType\x12\x08\n\x04UNIT\x10\x00\x12\x0c\n\x08WEIGHTED\x10\x01*\xcc\x01\n\x11PricingWeightTier\x12\r\n\tNO_WEIGHT\x10\x00\x12\x08\n\x04GRAM\x10\x01\x12\x0c\n\x08HALFGRAM\x10\x02\x12\x0f\n\x0bQUARTERGRAM\x10\x03\x12\x07\n\x03\x44UB\x10\x04\x12\n\n\x06\x45IGHTH\x10\x05\x12\x0b\n\x07QUARTER\x10\x06\x12\x08\n\x04HALF\x10\x07\x12\t\n\x05OUNCE\x10\x08\x12\x10\n\x0cQUARTERPOUND\x10\t\x12\r\n\tHALFPOUND\x10\n\x12\t\n\x05POUND\x10\x0b\x12\x08\n\x04KILO\x10\x0c\x12\x07\n\x03TON\x10\r\x12\t\n\x05OTHER\x10\x63\x42\x45\n%io.opencannabis.schema.product.structB\x12ProductPricingSpecH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_commerce_dot_Currency__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_pricing_dot_SaleDescriptor__pb2.DESCRIPTOR,])

_PRICINGTYPE = _descriptor.EnumDescriptor(
  name='PricingType',
  full_name='opencannabis.structs.pricing.PricingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNIT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEIGHTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1024,
  serialized_end=1061,
)
_sym_db.RegisterEnumDescriptor(_PRICINGTYPE)

PricingType = enum_type_wrapper.EnumTypeWrapper(_PRICINGTYPE)
_PRICINGWEIGHTTIER = _descriptor.EnumDescriptor(
  name='PricingWeightTier',
  full_name='opencannabis.structs.pricing.PricingWeightTier',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_WEIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRAM', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HALFGRAM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUARTERGRAM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUB', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EIGHTH', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUARTER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HALF', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUNCE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUARTERPOUND', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HALFPOUND', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='POUND', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KILO', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TON', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OTHER', index=14, number=99,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1064,
  serialized_end=1268,
)
_sym_db.RegisterEnumDescriptor(_PRICINGWEIGHTTIER)

PricingWeightTier = enum_type_wrapper.EnumTypeWrapper(_PRICINGWEIGHTTIER)
UNIT = 0
WEIGHTED = 1
NO_WEIGHT = 0
GRAM = 1
HALFGRAM = 2
QUARTERGRAM = 3
DUB = 4
EIGHTH = 5
QUARTER = 6
HALF = 7
OUNCE = 8
QUARTERPOUND = 9
HALFPOUND = 10
POUND = 11
KILO = 12
TON = 13
OTHER = 99



_PRICINGTIERAVAILABILITY = _descriptor.Descriptor(
  name='PricingTierAvailability',
  full_name='opencannabis.structs.pricing.PricingTierAvailability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offered', full_name='opencannabis.structs.pricing.PricingTierAvailability.offered', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available', full_name='opencannabis.structs.pricing.PricingTierAvailability.available', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=236,
)


_UNITPRICINGDESCRIPTOR = _descriptor.Descriptor(
  name='UnitPricingDescriptor',
  full_name='opencannabis.structs.pricing.UnitPricingDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='opencannabis.structs.pricing.UnitPricingDescriptor.price', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.structs.pricing.UnitPricingDescriptor.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='discounts', full_name='opencannabis.structs.pricing.UnitPricingDescriptor.discounts', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=451,
)


_WEIGHTEDPRICINGDESCRIPTOR = _descriptor.Descriptor(
  name='WeightedPricingDescriptor',
  full_name='opencannabis.structs.pricing.WeightedPricingDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight', full_name='opencannabis.structs.pricing.WeightedPricingDescriptor.weight', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tier', full_name='opencannabis.structs.pricing.WeightedPricingDescriptor.tier', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight_in_grams', full_name='opencannabis.structs.pricing.WeightedPricingDescriptor.weight_in_grams', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=638,
)


_PRICINGDESCRIPTOR = _descriptor.Descriptor(
  name='PricingDescriptor',
  full_name='opencannabis.structs.pricing.PricingDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.structs.pricing.PricingDescriptor.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.structs.pricing.PricingDescriptor.unit', index=1,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weighted', full_name='opencannabis.structs.pricing.PricingDescriptor.weighted', index=2,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tier', full_name='opencannabis.structs.pricing.PricingDescriptor.tier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=641,
  serialized_end=871,
)


_PRODUCTPRICING = _descriptor.Descriptor(
  name='ProductPricing',
  full_name='opencannabis.structs.pricing.ProductPricing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='discounts', full_name='opencannabis.structs.pricing.ProductPricing.discounts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manifest', full_name='opencannabis.structs.pricing.ProductPricing.manifest', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=1022,
)

_UNITPRICINGDESCRIPTOR.fields_by_name['price'].message_type = opencannabis_dot_commerce_dot_Currency__pb2._CURRENCYVALUE
_UNITPRICINGDESCRIPTOR.fields_by_name['status'].message_type = _PRICINGTIERAVAILABILITY
_UNITPRICINGDESCRIPTOR.fields_by_name['discounts'].message_type = opencannabis_dot_structs_dot_pricing_dot_SaleDescriptor__pb2._SALEDESCRIPTOR
_WEIGHTEDPRICINGDESCRIPTOR.fields_by_name['weight'].enum_type = _PRICINGWEIGHTTIER
_WEIGHTEDPRICINGDESCRIPTOR.fields_by_name['tier'].message_type = _UNITPRICINGDESCRIPTOR
_PRICINGDESCRIPTOR.fields_by_name['type'].enum_type = _PRICINGTYPE
_PRICINGDESCRIPTOR.fields_by_name['unit'].message_type = _UNITPRICINGDESCRIPTOR
_PRICINGDESCRIPTOR.fields_by_name['weighted'].message_type = _WEIGHTEDPRICINGDESCRIPTOR
_PRICINGDESCRIPTOR.oneofs_by_name['tier'].fields.append(
  _PRICINGDESCRIPTOR.fields_by_name['unit'])
_PRICINGDESCRIPTOR.fields_by_name['unit'].containing_oneof = _PRICINGDESCRIPTOR.oneofs_by_name['tier']
_PRICINGDESCRIPTOR.oneofs_by_name['tier'].fields.append(
  _PRICINGDESCRIPTOR.fields_by_name['weighted'])
_PRICINGDESCRIPTOR.fields_by_name['weighted'].containing_oneof = _PRICINGDESCRIPTOR.oneofs_by_name['tier']
_PRODUCTPRICING.fields_by_name['discounts'].message_type = opencannabis_dot_structs_dot_pricing_dot_SaleDescriptor__pb2._SALEDESCRIPTOR
_PRODUCTPRICING.fields_by_name['manifest'].message_type = _PRICINGDESCRIPTOR
DESCRIPTOR.message_types_by_name['PricingTierAvailability'] = _PRICINGTIERAVAILABILITY
DESCRIPTOR.message_types_by_name['UnitPricingDescriptor'] = _UNITPRICINGDESCRIPTOR
DESCRIPTOR.message_types_by_name['WeightedPricingDescriptor'] = _WEIGHTEDPRICINGDESCRIPTOR
DESCRIPTOR.message_types_by_name['PricingDescriptor'] = _PRICINGDESCRIPTOR
DESCRIPTOR.message_types_by_name['ProductPricing'] = _PRODUCTPRICING
DESCRIPTOR.enum_types_by_name['PricingType'] = _PRICINGTYPE
DESCRIPTOR.enum_types_by_name['PricingWeightTier'] = _PRICINGWEIGHTTIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PricingTierAvailability = _reflection.GeneratedProtocolMessageType('PricingTierAvailability', (_message.Message,), {
  'DESCRIPTOR' : _PRICINGTIERAVAILABILITY,
  '__module__' : 'opencannabis.structs.pricing.PricingDescriptor_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.pricing.PricingTierAvailability)
  })
_sym_db.RegisterMessage(PricingTierAvailability)

UnitPricingDescriptor = _reflection.GeneratedProtocolMessageType('UnitPricingDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _UNITPRICINGDESCRIPTOR,
  '__module__' : 'opencannabis.structs.pricing.PricingDescriptor_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.pricing.UnitPricingDescriptor)
  })
_sym_db.RegisterMessage(UnitPricingDescriptor)

WeightedPricingDescriptor = _reflection.GeneratedProtocolMessageType('WeightedPricingDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHTEDPRICINGDESCRIPTOR,
  '__module__' : 'opencannabis.structs.pricing.PricingDescriptor_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.pricing.WeightedPricingDescriptor)
  })
_sym_db.RegisterMessage(WeightedPricingDescriptor)

PricingDescriptor = _reflection.GeneratedProtocolMessageType('PricingDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _PRICINGDESCRIPTOR,
  '__module__' : 'opencannabis.structs.pricing.PricingDescriptor_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.pricing.PricingDescriptor)
  })
_sym_db.RegisterMessage(PricingDescriptor)

ProductPricing = _reflection.GeneratedProtocolMessageType('ProductPricing', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTPRICING,
  '__module__' : 'opencannabis.structs.pricing.PricingDescriptor_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.pricing.ProductPricing)
  })
_sym_db.RegisterMessage(ProductPricing)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.inventory.rfid`
  --------------------------------
  Definitions related to RFID-powered inventory (typically over LLRP).

"""

# `opencannabis.inventory.rfid`



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/inventory/InventoryProduct.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2
from opencannabis.commerce import Item_pb2 as opencannabis_dot_commerce_dot_Item__pb2
from opencannabis.products.menu import Menu_pb2 as opencannabis_dot_products_dot_menu_dot_Menu__pb2
from opencannabis.structs.pricing import PricingDescriptor_pb2 as opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/inventory/InventoryProduct.proto',
  package='opencannabis.inventory',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.inventoryH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-opencannabis/inventory/InventoryProduct.proto\x12\x16opencannabis.inventory\x1a\x19gust/core/datamodel.proto\x1a\"opencannabis/base/ProductKey.proto\x1a#opencannabis/temporal/Instant.proto\x1a opencannabis/commerce/Item.proto\x1a%opencannabis/products/menu/Menu.proto\x1a\x34opencannabis/structs/pricing/PricingDescriptor.proto\"P\n\x0cInventoryKey\x12\x32\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKeyB\x06\xc2\xb5\x03\x02\x08\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"o\n\x14InventoryCoordinates\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0c\n\x04rack\x18\x03 \x01(\t\x12\r\n\x05shelf\x18\x04 \x01(\t\x12\x0b\n\x03\x62in\x18\x05 \x01(\t\x12\r\n\x05\x62\x61tch\x18\x06 \x01(\t\"\xb8\x01\n\x0fInventoryAmount\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).opencannabis.structs.pricing.PricingType\x12\x0e\n\x04unit\x18\x02 \x01(\x08H\x00\x12\x41\n\x06weight\x18\x03 \x01(\x0e\x32/.opencannabis.structs.pricing.PricingWeightTierH\x00\x12\x10\n\x08quantity\x18\x04 \x01(\x04\x42\x07\n\x05\x62\x61sis\"\xb6\x03\n\x0eInventoryState\x12=\n\x06status\x18\x01 \x01(\x0e\x32-.opencannabis.inventory.InventoryState.Status\x12\x41\n\x0b\x63oordinates\x18\x02 \x01(\x0b\x32,.opencannabis.inventory.InventoryCoordinates\x12\x14\n\x0c\x66it_for_sale\x18\x03 \x01(\x08\x12\x37\n\x06\x61mount\x18\x04 \x01(\x0b\x32\'.opencannabis.inventory.InventoryAmount\x12/\n\x07\x63reated\x18\x62 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x30\n\x08modified\x18\x63 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\"p\n\x06Status\x12\x10\n\x0cUNRECONCILED\x10\x00\x12\r\n\tRECEIVING\x10\x01\x12\x0e\n\nQUARANTINE\x10\x02\x12\x0b\n\x07ON_HAND\x10\x03\x12\x0c\n\x08\x46OR_SALE\x10\x04\x12\x0b\n\x07\x43LAIMED\x10\x05\x12\r\n\tCOMMITTED\x10\x06\"\xc1\x02\n\x10InventoryProduct\x12\x31\n\x03key\x18\x01 \x01(\x0b\x32$.opencannabis.inventory.InventoryKey\x12\x0b\n\x03sku\x18\x02 \x03(\t\x12\x33\n\x07variant\x18\x03 \x03(\x0b\x32\".opencannabis.commerce.VariantSpec\x12\x35\n\x05state\x18\n \x01(\x0b\x32&.opencannabis.inventory.InventoryState\x12\x37\n\x07history\x18\x0b \x03(\x0b\x32&.opencannabis.inventory.InventoryState\x12\x35\n\x04item\x18\x14 \x01(\x0b\x32\'.opencannabis.products.menu.MenuProduct:\x11\x8a\xf7\x02\r\x08\x02\x12\tinventoryB,\n io.opencannabis.schema.inventoryH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Item__pb2.DESCRIPTOR,opencannabis_dot_products_dot_menu_dot_Menu__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2.DESCRIPTOR,])



_INVENTORYSTATE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='opencannabis.inventory.InventoryState.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNRECONCILED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECEIVING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUARANTINE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ON_HAND', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOR_SALE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLAIMED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMITTED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1009,
  serialized_end=1121,
)
_sym_db.RegisterEnumDescriptor(_INVENTORYSTATE_STATUS)


_INVENTORYKEY = _descriptor.Descriptor(
  name='InventoryKey',
  full_name='opencannabis.inventory.InventoryKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.inventory.InventoryKey.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='opencannabis.inventory.InventoryKey.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=380,
)


_INVENTORYCOORDINATES = _descriptor.Descriptor(
  name='InventoryCoordinates',
  full_name='opencannabis.inventory.InventoryCoordinates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.inventory.InventoryCoordinates.location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='opencannabis.inventory.InventoryCoordinates.zone', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rack', full_name='opencannabis.inventory.InventoryCoordinates.rack', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shelf', full_name='opencannabis.inventory.InventoryCoordinates.shelf', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bin', full_name='opencannabis.inventory.InventoryCoordinates.bin', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch', full_name='opencannabis.inventory.InventoryCoordinates.batch', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=493,
)


_INVENTORYAMOUNT = _descriptor.Descriptor(
  name='InventoryAmount',
  full_name='opencannabis.inventory.InventoryAmount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.inventory.InventoryAmount.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.inventory.InventoryAmount.unit', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='opencannabis.inventory.InventoryAmount.weight', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='opencannabis.inventory.InventoryAmount.quantity', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='basis', full_name='opencannabis.inventory.InventoryAmount.basis',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=496,
  serialized_end=680,
)


_INVENTORYSTATE = _descriptor.Descriptor(
  name='InventoryState',
  full_name='opencannabis.inventory.InventoryState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.inventory.InventoryState.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='opencannabis.inventory.InventoryState.coordinates', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fit_for_sale', full_name='opencannabis.inventory.InventoryState.fit_for_sale', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='opencannabis.inventory.InventoryState.amount', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='opencannabis.inventory.InventoryState.created', index=4,
      number=98, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified', full_name='opencannabis.inventory.InventoryState.modified', index=5,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INVENTORYSTATE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=1121,
)


_INVENTORYPRODUCT = _descriptor.Descriptor(
  name='InventoryProduct',
  full_name='opencannabis.inventory.InventoryProduct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.inventory.InventoryProduct.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sku', full_name='opencannabis.inventory.InventoryProduct.sku', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variant', full_name='opencannabis.inventory.InventoryProduct.variant', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='opencannabis.inventory.InventoryProduct.state', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='history', full_name='opencannabis.inventory.InventoryProduct.history', index=4,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='opencannabis.inventory.InventoryProduct.item', index=5,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\r\010\002\022\tinventory',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1445,
)

_INVENTORYKEY.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_INVENTORYAMOUNT.fields_by_name['type'].enum_type = opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2._PRICINGTYPE
_INVENTORYAMOUNT.fields_by_name['weight'].enum_type = opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2._PRICINGWEIGHTTIER
_INVENTORYAMOUNT.oneofs_by_name['basis'].fields.append(
  _INVENTORYAMOUNT.fields_by_name['unit'])
_INVENTORYAMOUNT.fields_by_name['unit'].containing_oneof = _INVENTORYAMOUNT.oneofs_by_name['basis']
_INVENTORYAMOUNT.oneofs_by_name['basis'].fields.append(
  _INVENTORYAMOUNT.fields_by_name['weight'])
_INVENTORYAMOUNT.fields_by_name['weight'].containing_oneof = _INVENTORYAMOUNT.oneofs_by_name['basis']
_INVENTORYSTATE.fields_by_name['status'].enum_type = _INVENTORYSTATE_STATUS
_INVENTORYSTATE.fields_by_name['coordinates'].message_type = _INVENTORYCOORDINATES
_INVENTORYSTATE.fields_by_name['amount'].message_type = _INVENTORYAMOUNT
_INVENTORYSTATE.fields_by_name['created'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_INVENTORYSTATE.fields_by_name['modified'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_INVENTORYSTATE_STATUS.containing_type = _INVENTORYSTATE
_INVENTORYPRODUCT.fields_by_name['key'].message_type = _INVENTORYKEY
_INVENTORYPRODUCT.fields_by_name['variant'].message_type = opencannabis_dot_commerce_dot_Item__pb2._VARIANTSPEC
_INVENTORYPRODUCT.fields_by_name['state'].message_type = _INVENTORYSTATE
_INVENTORYPRODUCT.fields_by_name['history'].message_type = _INVENTORYSTATE
_INVENTORYPRODUCT.fields_by_name['item'].message_type = opencannabis_dot_products_dot_menu_dot_Menu__pb2._MENUPRODUCT
DESCRIPTOR.message_types_by_name['InventoryKey'] = _INVENTORYKEY
DESCRIPTOR.message_types_by_name['InventoryCoordinates'] = _INVENTORYCOORDINATES
DESCRIPTOR.message_types_by_name['InventoryAmount'] = _INVENTORYAMOUNT
DESCRIPTOR.message_types_by_name['InventoryState'] = _INVENTORYSTATE
DESCRIPTOR.message_types_by_name['InventoryProduct'] = _INVENTORYPRODUCT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InventoryKey = _reflection.GeneratedProtocolMessageType('InventoryKey', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYKEY,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryKey)
  })
_sym_db.RegisterMessage(InventoryKey)

InventoryCoordinates = _reflection.GeneratedProtocolMessageType('InventoryCoordinates', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYCOORDINATES,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryCoordinates)
  })
_sym_db.RegisterMessage(InventoryCoordinates)

InventoryAmount = _reflection.GeneratedProtocolMessageType('InventoryAmount', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYAMOUNT,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryAmount)
  })
_sym_db.RegisterMessage(InventoryAmount)

InventoryState = _reflection.GeneratedProtocolMessageType('InventoryState', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYSTATE,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryState)
  })
_sym_db.RegisterMessage(InventoryState)

InventoryProduct = _reflection.GeneratedProtocolMessageType('InventoryProduct', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYPRODUCT,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryProduct)
  })
_sym_db.RegisterMessage(InventoryProduct)


DESCRIPTOR._options = None
_INVENTORYKEY.fields_by_name['key']._options = None
_INVENTORYPRODUCT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/inventory/rfid/RFID.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/inventory/rfid/RFID.proto',
  package='opencannabis.inventory.rfid',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.inventoryH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&opencannabis/inventory/rfid/RFID.proto\x12\x1bopencannabis.inventory.rfid\x1a\x19gust/core/datamodel.proto\"\x89\x04\n\x06Reader\x12]\n\x04name\x18\x01 \x01(\tBO\xc2\xb5\x03K\x12ICanonical label/name for the reader device involved in an RFID operation.\x12X\n\x03mac\x18\x02 \x01(\tBK\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x41\x12?MAC address of the reader device involved in an RFID operation.\x12P\n\x02ip\x18\x03 \x01(\tBD\xc2\xb5\x03@\x12>IP address of the reader device involved in an RFID operation.\x12{\n\x06vendor\x18\x04 \x01(\x0e\x32).opencannabis.inventory.rfid.ReaderVendorB@\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x36\x12\x34Vendor for the reader involved in an RFID operation.\x12w\n\x05model\x18\x05 \x01(\x0e\x32(.opencannabis.inventory.rfid.ReaderModelB>\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x34\x12\x32Model of the reader involved in an RFID operation.\"X\n\x07\x41ntenna\x12M\n\x05index\x18\x01 \x01(\rB>\xc2\xb5\x03:\x12\x38Port index for the antenna that produced some operation.\"\x85\x02\n\x03Tag\x12\\\n\x03tid\x18\x01 \x01(\tBO\xc2\xb5\x03K\x12ITag ID, assigned to the tag at manufacturing time and never over-written.\x12>\n\x07payload\x18\x02 \x01(\x0c\x42-\xca\xb5\x03\x02\x10\x01\xc2\xb5\x03#\x12!Raw content encoded onto the tag.\x12U\n\x03\x65pc\x18\n \x01(\tBF\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03<\x12:Electronic Product Code (EPC) that was present on the tag.H\x00\x42\t\n\x07\x63ontent*@\n\x0cReaderVendor\x12\x17\n\x13UNRECOGNIZED_VENDOR\x10\x00\x12\x0c\n\x06IMPINJ\x10\x9a\xca\x01\x12\t\n\x05\x41LIEN\x10\x02*\xad\x01\n\x0bReaderModel\x12\x17\n\x13UNRECOGNIZED_READER\x10\x00\x12\x11\n\rSPEEDWAY_R120\x10\x01\x12\x11\n\rSPEEDWAY_R220\x10\x02\x12\x13\n\rSPEEDWAY_R420\x10\xea\x90z\x12\x14\n\x10SPEEDWAY_XPORTAL\x10\x04\x12\x11\n\rALIEN_ALRH450\x10\x05\x12\x0e\n\nALIEN_F800\x10\x06\x12\x11\n\rALIEN_ALR9680\x10\x07\x42,\n io.opencannabis.schema.inventoryH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])

_READERVENDOR = _descriptor.EnumDescriptor(
  name='ReaderVendor',
  full_name='opencannabis.inventory.rfid.ReaderVendor',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNRECOGNIZED_VENDOR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMPINJ', index=1, number=25882,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=976,
  serialized_end=1040,
)
_sym_db.RegisterEnumDescriptor(_READERVENDOR)

ReaderVendor = enum_type_wrapper.EnumTypeWrapper(_READERVENDOR)
_READERMODEL = _descriptor.EnumDescriptor(
  name='ReaderModel',
  full_name='opencannabis.inventory.rfid.ReaderModel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNRECOGNIZED_READER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEEDWAY_R120', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEEDWAY_R220', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEEDWAY_R420', index=3, number=2001002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEEDWAY_XPORTAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIEN_ALRH450', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIEN_F800', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIEN_ALR9680', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1043,
  serialized_end=1216,
)
_sym_db.RegisterEnumDescriptor(_READERMODEL)

ReaderModel = enum_type_wrapper.EnumTypeWrapper(_READERMODEL)
UNRECOGNIZED_VENDOR = 0
IMPINJ = 25882
ALIEN = 2
UNRECOGNIZED_READER = 0
SPEEDWAY_R120 = 1
SPEEDWAY_R220 = 2
SPEEDWAY_R420 = 2001002
SPEEDWAY_XPORTAL = 4
ALIEN_ALRH450 = 5
ALIEN_F800 = 6
ALIEN_ALR9680 = 7



_READER = _descriptor.Descriptor(
  name='Reader',
  full_name='opencannabis.inventory.rfid.Reader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.inventory.rfid.Reader.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003K\022ICanonical label/name for the reader device involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac', full_name='opencannabis.inventory.rfid.Reader.mac', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003A\022?MAC address of the reader device involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='opencannabis.inventory.rfid.Reader.ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003@\022>IP address of the reader device involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='opencannabis.inventory.rfid.Reader.vendor', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\0036\0224Vendor for the reader involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='opencannabis.inventory.rfid.Reader.model', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\0034\0222Model of the reader involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=620,
)


_ANTENNA = _descriptor.Descriptor(
  name='Antenna',
  full_name='opencannabis.inventory.rfid.Antenna',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='opencannabis.inventory.rfid.Antenna.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003:\0228Port index for the antenna that produced some operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=710,
)


_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='opencannabis.inventory.rfid.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tid', full_name='opencannabis.inventory.rfid.Tag.tid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003K\022ITag ID, assigned to the tag at manufacturing time and never over-written.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='opencannabis.inventory.rfid.Tag.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001\302\265\003#\022!Raw content encoded onto the tag.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epc', full_name='opencannabis.inventory.rfid.Tag.epc', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003<\022:Electronic Product Code (EPC) that was present on the tag.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='opencannabis.inventory.rfid.Tag.content',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=713,
  serialized_end=974,
)

_READER.fields_by_name['vendor'].enum_type = _READERVENDOR
_READER.fields_by_name['model'].enum_type = _READERMODEL
_TAG.oneofs_by_name['content'].fields.append(
  _TAG.fields_by_name['epc'])
_TAG.fields_by_name['epc'].containing_oneof = _TAG.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['Reader'] = _READER
DESCRIPTOR.message_types_by_name['Antenna'] = _ANTENNA
DESCRIPTOR.message_types_by_name['Tag'] = _TAG
DESCRIPTOR.enum_types_by_name['ReaderVendor'] = _READERVENDOR
DESCRIPTOR.enum_types_by_name['ReaderModel'] = _READERMODEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Reader = _reflection.GeneratedProtocolMessageType('Reader', (_message.Message,), {
  'DESCRIPTOR' : _READER,
  '__module__' : 'opencannabis.inventory.rfid.RFID_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.Reader)
  })
_sym_db.RegisterMessage(Reader)

Antenna = _reflection.GeneratedProtocolMessageType('Antenna', (_message.Message,), {
  'DESCRIPTOR' : _ANTENNA,
  '__module__' : 'opencannabis.inventory.rfid.RFID_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.Antenna)
  })
_sym_db.RegisterMessage(Antenna)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'opencannabis.inventory.rfid.RFID_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.Tag)
  })
_sym_db.RegisterMessage(Tag)


DESCRIPTOR._options = None
_READER.fields_by_name['name']._options = None
_READER.fields_by_name['mac']._options = None
_READER.fields_by_name['ip']._options = None
_READER.fields_by_name['vendor']._options = None
_READER.fields_by_name['model']._options = None
_ANTENNA.fields_by_name['index']._options = None
_TAG.fields_by_name['tid']._options = None
_TAG.fields_by_name['payload']._options = None
_TAG.fields_by_name['epc']._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.accounting`
  ---------------------------
  Accounting models, including taxes, GL accounts, and so on.

"""

# `opencannabis.accounting`
from .Taxes_pb2 import Taxes



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/Species.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/Species.proto',
  package='opencannabis.structs',
  syntax='proto3',
  serialized_options=b'\n%io.opencannabis.schema.product.structB\017MaterialSpeciesH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/structs/Species.proto\x12\x14opencannabis.structs*d\n\x07Species\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06SATIVA\x10\x01\x12\x11\n\rHYBRID_SATIVA\x10\x02\x12\n\n\x06HYBRID\x10\x03\x12\x11\n\rHYBRID_INDICA\x10\x04\x12\n\n\x06INDICA\x10\x05\x42\x42\n%io.opencannabis.schema.product.structB\x0fMaterialSpeciesH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_SPECIES = _descriptor.EnumDescriptor(
  name='Species',
  full_name='opencannabis.structs.Species',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SATIVA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HYBRID_SATIVA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HYBRID', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HYBRID_INDICA', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDICA', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=60,
  serialized_end=160,
)
_sym_db.RegisterEnumDescriptor(_SPECIES)

Species = enum_type_wrapper.EnumTypeWrapper(_SPECIES)
UNSPECIFIED = 0
SATIVA = 1
HYBRID_SATIVA = 2
HYBRID = 3
HYBRID_INDICA = 4
INDICA = 5


DESCRIPTOR.enum_types_by_name['Species'] = _SPECIES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/crypto/Signature.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.crypto.primitives import Keys_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2
from opencannabis.crypto.primitives import Integrity_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/crypto/Signature.proto',
  package='opencannabis.crypto',
  syntax='proto3',
  serialized_options=b'\n\035io.opencannabis.schema.cryptoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/crypto/Signature.proto\x12\x13opencannabis.crypto\x1a)opencannabis/crypto/primitives/Keys.proto\x1a.opencannabis/crypto/primitives/Integrity.proto\"\xab\x01\n\tSignature\x12\x34\n\npublic_key\x18\x01 \x01(\x0b\x32 .opencannabis.crypto.KeyMaterial\x12.\n\x0b\x66ingerprint\x18\x02 \x01(\x0b\x32\x19.opencannabis.crypto.Hash\x12\r\n\x03raw\x18\x05 \x01(\x0cH\x00\x12\r\n\x03\x62\x36\x34\x18\x06 \x01(\tH\x00\x12\r\n\x03hex\x18\x07 \x01(\tH\x00\x42\x0b\n\tsignatureB)\n\x1dio.opencannabis.schema.cryptoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2.DESCRIPTOR,opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2.DESCRIPTOR,])




_SIGNATURE = _descriptor.Descriptor(
  name='Signature',
  full_name='opencannabis.crypto.Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='opencannabis.crypto.Signature.public_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='opencannabis.crypto.Signature.fingerprint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='opencannabis.crypto.Signature.raw', index=2,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b64', full_name='opencannabis.crypto.Signature.b64', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hex', full_name='opencannabis.crypto.Signature.hex', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='signature', full_name='opencannabis.crypto.Signature.signature',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=152,
  serialized_end=323,
)

_SIGNATURE.fields_by_name['public_key'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._KEYMATERIAL
_SIGNATURE.fields_by_name['fingerprint'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2._HASH
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['raw'])
_SIGNATURE.fields_by_name['raw'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['b64'])
_SIGNATURE.fields_by_name['b64'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['hex'])
_SIGNATURE.fields_by_name['hex'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
DESCRIPTOR.message_types_by_name['Signature'] = _SIGNATURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Signature = _reflection.GeneratedProtocolMessageType('Signature', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATURE,
  '__module__' : 'opencannabis.crypto.Signature_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.Signature)
  })
_sym_db.RegisterMessage(Signature)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.crypto.primitives`
  -------------------------------------
  Primitive objects and definitions related to cryptography.

"""

# `opencannabis.crypto.primitives`



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/Brand.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.content import Colors_pb2 as opencannabis_dot_content_dot_Colors__pb2
from opencannabis.content import Name_pb2 as opencannabis_dot_content_dot_Name__pb2
from opencannabis.content import Content_pb2 as opencannabis_dot_content_dot_Content__pb2
from opencannabis.media import MediaKey_pb2 as opencannabis_dot_media_dot_MediaKey__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/Brand.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\014BrandContentH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/content/Brand.proto\x12\x14opencannabis.content\x1a!opencannabis/content/Colors.proto\x1a\x1fopencannabis/content/Name.proto\x1a\"opencannabis/content/Content.proto\x1a!opencannabis/media/MediaKey.proto\"y\n\rRasterGraphic\x12\x34\n\x08standard\x18\x01 \x01(\x0b\x32\".opencannabis.media.MediaReference\x12\x32\n\x06retina\x18\x02 \x01(\x0b\x32\".opencannabis.media.MediaReference\"u\n\nBrandAsset\x12\x33\n\x06raster\x18\x01 \x01(\x0b\x32#.opencannabis.content.RasterGraphic\x12\x32\n\x06vector\x18\x02 \x01(\x0b\x32\".opencannabis.media.MediaReference\"\x8d\x02\n\x05\x42rand\x12(\n\x04name\x18\x01 \x01(\x0b\x32\x1a.opencannabis.content.Name\x12+\n\x06parent\x18\x02 \x01(\x0b\x32\x1b.opencannabis.content.Brand\x12.\n\x07summary\x18\x03 \x01(\x0b\x32\x1d.opencannabis.content.Content\x12/\n\x05media\x18\x14 \x03(\x0b\x32 .opencannabis.content.BrandAsset\x12\x30\n\x05theme\x18\x15 \x01(\x0b\x32!.opencannabis.content.ColorScheme\x12\x0c\n\x04slug\x18\x16 \x01(\t\x12\x0c\n\x04link\x18\x17 \x01(\tB8\n\x1eio.opencannabis.schema.contentB\x0c\x42randContentH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_content_dot_Colors__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Name__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Content__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaKey__pb2.DESCRIPTOR,])




_RASTERGRAPHIC = _descriptor.Descriptor(
  name='RasterGraphic',
  full_name='opencannabis.content.RasterGraphic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='standard', full_name='opencannabis.content.RasterGraphic.standard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retina', full_name='opencannabis.content.RasterGraphic.retina', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=318,
)


_BRANDASSET = _descriptor.Descriptor(
  name='BrandAsset',
  full_name='opencannabis.content.BrandAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raster', full_name='opencannabis.content.BrandAsset.raster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='opencannabis.content.BrandAsset.vector', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=437,
)


_BRAND = _descriptor.Descriptor(
  name='Brand',
  full_name='opencannabis.content.Brand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.content.Brand.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='opencannabis.content.Brand.parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='opencannabis.content.Brand.summary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='opencannabis.content.Brand.media', index=3,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theme', full_name='opencannabis.content.Brand.theme', index=4,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='opencannabis.content.Brand.slug', index=5,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='opencannabis.content.Brand.link', index=6,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=709,
)

_RASTERGRAPHIC.fields_by_name['standard'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAREFERENCE
_RASTERGRAPHIC.fields_by_name['retina'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAREFERENCE
_BRANDASSET.fields_by_name['raster'].message_type = _RASTERGRAPHIC
_BRANDASSET.fields_by_name['vector'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAREFERENCE
_BRAND.fields_by_name['name'].message_type = opencannabis_dot_content_dot_Name__pb2._NAME
_BRAND.fields_by_name['parent'].message_type = _BRAND
_BRAND.fields_by_name['summary'].message_type = opencannabis_dot_content_dot_Content__pb2._CONTENT
_BRAND.fields_by_name['media'].message_type = _BRANDASSET
_BRAND.fields_by_name['theme'].message_type = opencannabis_dot_content_dot_Colors__pb2._COLORSCHEME
DESCRIPTOR.message_types_by_name['RasterGraphic'] = _RASTERGRAPHIC
DESCRIPTOR.message_types_by_name['BrandAsset'] = _BRANDASSET
DESCRIPTOR.message_types_by_name['Brand'] = _BRAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RasterGraphic = _reflection.GeneratedProtocolMessageType('RasterGraphic', (_message.Message,), {
  'DESCRIPTOR' : _RASTERGRAPHIC,
  '__module__' : 'opencannabis.content.Brand_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.RasterGraphic)
  })
_sym_db.RegisterMessage(RasterGraphic)

BrandAsset = _reflection.GeneratedProtocolMessageType('BrandAsset', (_message.Message,), {
  'DESCRIPTOR' : _BRANDASSET,
  '__module__' : 'opencannabis.content.Brand_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.BrandAsset)
  })
_sym_db.RegisterMessage(BrandAsset)

Brand = _reflection.GeneratedProtocolMessageType('Brand', (_message.Message,), {
  'DESCRIPTOR' : _BRAND,
  '__module__' : 'opencannabis.content.Brand_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.Brand)
  })
_sym_db.RegisterMessage(Brand)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python

from setuptools import setup, find_packages

setup(
  name='opencannabis',
  version='1.0.1',
  description='OpenCannabis SDK for Python',
  author='Sam Gammon',
  author_email='sam.g@cookies.co',
  url='https://github.com/OpenCannabis/Python',
  packages=find_packages(
    exclude=[
        "*.tests",
        "*.tests.*",
        "tests.*",
        "tests",
        "*.pytests",
        "*.pytests.*",
        "pytests.*",
        "pytests",
        "gust",
        "gust*",
        "gust.*"
    ]
  ),
  classifiers=[
    "Development Status :: 4 - Beta",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: MIT License",
    "Operating System :: POSIX",
    "Programming Language :: Python :: 2",
    "Programming Language :: Python :: 2.6",
    "Programming Language :: Python :: 2.7",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
  ],
  requires=[
    'protobuf',
    'colorlog',
    'gust'
  ],
  install_requires=[
    'protobuf>=3.13.0',
    'colorlog>=4.2.1',
    'gust>=1.0.2'
  ],
)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.content`
  ---------------------------
  Models which hold structured / attribute-based and unstructured data which should be treated as content.

"""

# `opencannabis.content`



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.commerce.payments`
  -------------------------------------
  Models related to payments made by consumers during retail cannabis transactions.

"""

# `opencannabis.commerce.payments`



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/media/MediaOrientation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/media/MediaOrientation.proto',
  package='opencannabis.media',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.mediaB\024MediaItemOrientationH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)opencannabis/media/MediaOrientation.proto\x12\x12opencannabis.media*\x84\x01\n\x10MediaOrientation\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\t\n\x05RIGHT\x10\x03\x12\x0f\n\x0bUP_MIRRORED\x10\x04\x12\x11\n\rDOWN_MIRRORED\x10\x05\x12\x11\n\rLEFT_MIRRORED\x10\x06\x12\x12\n\x0eRIGHT_MIRRORED\x10\x07\x42>\n\x1cio.opencannabis.schema.mediaB\x14MediaItemOrientationH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_MEDIAORIENTATION = _descriptor.EnumDescriptor(
  name='MediaOrientation',
  full_name='opencannabis.media.MediaOrientation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UP_MIRRORED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN_MIRRORED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_MIRRORED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_MIRRORED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=66,
  serialized_end=198,
)
_sym_db.RegisterEnumDescriptor(_MEDIAORIENTATION)

MediaOrientation = enum_type_wrapper.EnumTypeWrapper(_MEDIAORIENTATION)
UP = 0
DOWN = 1
LEFT = 2
RIGHT = 3
UP_MIRRORED = 4
DOWN_MIRRORED = 5
LEFT_MIRRORED = 6
RIGHT_MIRRORED = 7


DESCRIPTOR.enum_types_by_name['MediaOrientation'] = _MEDIAORIENTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
